import 'package:flutter/material.dart';

import 'id_camera_widget.dart';

class MyMask extends CustomPainter {
  final Color outerBackgroundColor;
  final MaskType pathBorderType;

  MyMask({
    required this.outerBackgroundColor,
    this.pathBorderType = MaskType.passport,
  });
  @override
  void paint(Canvas canvas, Size size) {
    final outerRect = RRect.fromLTRBR(
      0,
      0,
      size.width,
      size.height,
      const Radius.circular(0.00001),
    );

    late RRect innerRect;
    if (pathBorderType == MaskType.idCard) {
      innerRect = RRect.fromLTRBR(
        size.width * 0.05,
        (size.height / 2) - ((size.width * 0.9) / 3 * 2) / 2,
        size.width * 0.95,
        (size.height / 2) + ((size.width * 0.9) / 3 * 2) / 2,
        const Radius.circular(16),
      );
    } else {
      innerRect = RRect.fromLTRBR(
        size.width * 0.05,
        (size.height / 2) - ((size.width * 0.9) / 3 * 4) / 2,
        size.width * 0.95,
        (size.height / 2) + ((size.width * 0.9) / 3 * 4) / 2,
        const Radius.circular(16),
      );
    }

    // draw outer rectangle with a hole in center
    canvas.drawPath(
      Path.combine(
        PathOperation.difference,
        Path()..addRRect(outerRect),
        Path()
          ..addRRect(innerRect)
          ..close(),
      ),
      Paint()..color = outerBackgroundColor,
    );

    // draw inner rectangle above hole in the center
    canvas.drawPath(
        Path()..addRRect(innerRect),
        Paint()
          ..color = Colors.white
          ..strokeWidth = 2
          ..style = PaintingStyle.stroke);
  }

  @override
  bool shouldRepaint(CustomPainter oldDelegate) {
    return false;
  }
}
